@@ -56,29 +56,6 @@ typedef enum {
 } GpkInfoStatusEnum;
 
 /* constants defined in previous versions */
-#if (!PK_CHECK_VERSION(0,5,6))
-#define PK_ERROR_ENUM_UPDATE_FAILED_DUE_TO_RUNNING_PROCESS		(PK_ERROR_ENUM_PACKAGE_FAILED_TO_REMOVE + 1)
-#endif
-
-#if (!PK_CHECK_VERSION(0,5,7))
-#define PK_MESSAGE_ENUM_REPO_FOR_DEVELOPERS_ONLY			(PK_MESSAGE_ENUM_REPO_METADATA_DOWNLOAD_FAILED + 1)
-#endif
-
-#if (!PK_CHECK_VERSION(0,6,2))
-#define PK_CLIENT_ERROR_DECLINED_SIMULATION				 PK_CLIENT_ERROR_FAILED
-#define PK_ERROR_ENUM_PACKAGE_DATABASE_CHANGED				 PK_ERROR_ENUM_LAST
-#define PK_CLIENT_ERROR_LAST						(PK_CLIENT_ERROR_DECLINED_SIMULATION + 1)
-#endif
-
-#if (!PK_CHECK_VERSION(0,6,3))
-#define PK_ERROR_ENUM_PROVIDE_TYPE_NOT_SUPPORTED			(PK_ERROR_ENUM_PACKAGE_DATABASE_CHANGED + 1)
-#endif
-
-#if (!PK_CHECK_VERSION(0,6,4))
-#define PK_MESSAGE_ENUM_OTHER_UPDATES_HELD_BACK				(PK_MESSAGE_ENUM_REPO_FOR_DEVELOPERS_ONLY + 1)
-#define PK_ERROR_ENUM_INSTALL_ROOT_INVALID				(PK_ERROR_ENUM_PROVIDE_TYPE_NOT_SUPPORTED + 1)
-#endif
-
 #if (!PK_CHECK_VERSION(0,6,11))
 #define PK_ROLE_ENUM_UPGRADE_SYSTEM					(PK_ROLE_ENUM_SIMULATE_UPDATE_PACKAGES + 1)
 #endif
